==> img0ch-2.1.11.zip: img0ch/_template/default/read.cs <==
<html>
<head>
<title><?cs var:Subject ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<?cs var:META ?>
</head>
<body bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>">

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><hr><?cs /if ?>

<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
<?cs each:item = LinkStack ?><a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>"><?cs var:html_escape(item.start) ?>-</a>
<?cs /each ?>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?><br>

<?cs if:r100 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X1000𒴂Ă܂BcOȂS͕\܂B
</font><br></td></tr></table>
<?cs elif:r95 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X950𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs elif:r90 ?>
<table border="0"><tr><td bgcolor="yellow"><br><font color="black">
X900𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs /if ?>

<dl>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:Subject ?></font><br><br>

<?cs each:item = Thread ?><dt><?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:html_escape(item.date) ?></dt><dd><?cs var:item.text ?><br><br></dd>
<?cs /each ?>
</dl>

<font color=red face="Arial"><b><?cs var:html_escape(DatKByteSize) ?>KB</b></font>
<hr><center><a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(ResCount) ?>-n">VX̕\</a></center><hr>
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>

<a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>">O100</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>">100</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?>
<br><br>

<?cs if:!r100 ?>
<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="submit" value="">
OF<input type=text id="FROM" name="FROM" value="" size="19">
E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
<?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
<?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
<?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
<?cs /each ?></select><br><?cs /if ?>
<textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
<?cs if:UploadableFromRes ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
<small><?cs var:html_escape(VERSION) ?></small>
</form>
<?cs else ?>
<small><?cs var:html_escape(VERSION) ?></small>
<?cs /if ?>

</body>
</html>

==> img0ch-3.1.1.zip: img0ch/_template/default/read.cs <==
<html>
<head>
<title><?cs var:html_escape(Subject) ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<?cs var:META ?>
</head>
<body bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>">

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>

<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
<?cs each:item = LinkStack ?><a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>"><?cs var:html_escape(item.start) ?>-</a>
<?cs /each ?>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50" onclick="app.enableRedirectRenderer();app.redirectRenderer(this)">read.htmlɐ؂ւ</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?><br>

<?cs if:R100 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X<?cs var:html_escape(BBS_RES_MAX) ?>𒴂Ă܂BcOȂS͕\܂B
</font><br></td></tr></table>
<?cs elif:R95 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X<?cs var:html_escape(R95C) ?>𒴂Ă܂B<?cs var:html_escape(BBS_RES_MAX) ?>𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs elif:R90 ?>
<table border="0"><tr><td bgcolor="yellow"><br><font color="black">
X<?cs var:html_escape(R90C) ?>𒴂Ă܂B<?cs var:html_escape(BBS_RES_MAX) ?>𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs /if ?>

<dl>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:html_escape(Subject) ?></font><br><br>

<?cs each:item = Thread ?><dt><?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?></dt><dd><?cs var:item.text ?><br><br></dd>
<?cs /each ?>
</dl>

<font color=red face="Arial"><b><?cs var:html_escape(DatKByteSize) ?>KB</b></font>
<hr><center><a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(ResCount) ?>-n">VX̕\</a></center><hr>
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>

<a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>">O100</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>">100</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
<a href="<?cs var:html_escape(ReadCGIURI) ?>/l50" onclick="app.enableRedirectRenderer();app.redirectRenderer(this)">read.htmlɐ؂ւ</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?>
<br><br>

<?cs if:!r100 ?>
<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi?guid=on" enctype="multipart/form-data">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="submit" value="">
OF<input type=text id="FROM" name="FROM" value="" size="19">
E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
<?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
<?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
<?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
<?cs /each ?></select><br><?cs /if ?>
<textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
<?cs if:UploadableFromRes ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
<small><?cs var:html_escape(VERSION) ?></small>
</form>
<?cs else ?>
<small><?cs var:html_escape(VERSION) ?></small>
<?cs /if ?>

</body>
</html>
